@@ -1,4 +1,3 @@
-
 debug_levels <- c(
   fatal = 0,
   error = 1,
@@ -10,8 +9,8 @@ debug_levels <- c(
 
 get_debug_level <- function() {
   lvl <- tolower(Sys.getenv("ASCIICAST_DEBUG_LEVEL", "fatal"))
-  if (! lvl %in% names(debug_levels)) {
-    stop(cli::format_error(c(
+  if (!lvl %in% names(debug_levels)) {
+    throw(cli::format_error(c(
       "Invalid asciicast debug level in {.env ASCIICAST_DEBUG_LEVEL env
        var: {.code lvl}.",
       i = "It must be one of {.code {names(debug_levels)}}."
