@@ -1,6 +1,3 @@
-
-# nocov start
-
 # # Standalone file for better error handling ----------------------------
 #
 # If can allow package dependencies, then you are probably better off
@@ -130,9 +127,35 @@
 # ### 3.0.0 -- 2022-04-19
 #
 # * Major rewrite, use rlang compatible error objects. New API.
+#
+# ### 3.0.1 -- 2022-06-17
+#
+# * Remove the `rlang_error` and `rlang_trace` classes, because our new
+#   deparsed `call` column in the trace is not compatible with rlang.
+#
+# ### 3.0.2 -- 2022-08-01
+#
+# * Use a `procsrcref` column for processed source references.
+#   Otherwise testthat (and probably other rlang based packages), will
+#   pick up the `srcref` column, and they expect an `srcref` object there.
+#
+# ### 3.1.0 -- 2022-10-04
+#
+# * Add ANSI hyperlinks to stack traces, if we have a recent enough
+#   cli package that supports this.
+#
+# ### 3.1.1 -- 2022-11-17
+#
+# * Use `[[` instead of `$` to fix some partial matches.
+# * Use fully qualified `base::stop()` to enable overriding `stop()`
+#   in a package. (Makes sense if compat files use `stop()`.
+# * The `is_interactive()` function is now exported.
+#
+# ### 3.1.2 -- 2022-11-18
+#
+# * The `parent` condition can now be an interrupt.
 
 err <- local({
-
   # -- dependencies -----------------------------------------------------
   rstudio_detect <- rstudio$detect
 
@@ -159,7 +182,8 @@ err <- local({
     message <- .makeMessage(..., domain = domain)
     structure(
       list(message = message, call = call., srcref = srcref),
-      class = c("condition"))
+      class = c("condition")
+    )
   }
 
   #' Create a new error condition
@@ -176,7 +200,7 @@ err <- local({
 
   new_error <- function(..., call. = TRUE, srcref = NULL, domain = NA) {
     cond <- new_cond(..., call. = call., domain = domain, srcref = srcref)
-    class(cond) <- c("rlib_error_3_0", "rlib_error", "rlang_error", "error", "condition")
+    class(cond) <- c("rlib_error_3_0", "rlib_error", "error", "condition")
     cond
   }
 
@@ -203,10 +227,10 @@ err <- local({
       throw(new_error("Parent condition must be a condition object"))
     }
 
-    if (isTRUE(cond$call)) {
-      cond$call <- sys.call(-1) %||% sys.call()
-    } else if (identical(cond$call, FALSE)) {
-      cond$call <- NULL
+    if (isTRUE(cond[["call"]])) {
+      cond[["call"]] <- sys.call(-1) %||% sys.call()
+    } else if (identical(cond[["call"]], FALSE)) {
+      cond[["call"]] <- NULL
     }
 
     cond <- process_call(cond)
@@ -237,9 +261,11 @@ err <- local({
     # baseenv(), so it is almost as if it was in baseenv() itself, like
     # .Last.value. We save the print methods here as well, and then they
     # will be found automatically.
-    if (! "org:r-lib" %in% search()) {
-      do.call("attach", list(new.env(), pos = length(search()),
-                             name = "org:r-lib"))
+    if (!"org:r-lib" %in% search()) {
+      do.call("attach", list(new.env(),
+        pos = length(search()),
+        name = "org:r-lib"
+      ))
     }
     env <- as.environment("org:r-lib")
     env$.Last.error <- cond
@@ -250,13 +276,15 @@ err <- local({
 
     # If this is not an error, then we'll just return here. This allows
     # throwing interrupt conditions for example, with the same UI.
-    if (! inherits(cond, "error")) return(invisible())
+    if (!inherits(cond, "error")) {
+      return(invisible())
+    }
     .hide_from_trace <- NULL
 
     # Top-level handler, this is intended for testing only for now,
     # and its design might change.
     if (!is.null(th <- getOption("rlib_error_handler")) &&
-        is.function(th)) {
+      is.function(th)) {
       return(th(cond))
     }
 
@@ -285,7 +313,7 @@ err <- local({
     opts <- options(show.error.messages = FALSE)
     on.exit(options(opts), add = TRUE)
 
-    stop(cond)
+    base::stop(cond)
   }
 
   # -- rethrow with parent -----------------------------------------------
@@ -300,20 +328,24 @@ err <- local({
   #' @param err Error object or message to use for the child error.
   #' @param call Call to use in the re-thrown error. See [throw()].
 
-  chain_error <- function(expr, err, call = sys.call(-1)) {
+  chain_error <- function(expr, err, call = sys.call(-1), srcref = NULL) {
     .hide_from_trace <- 1
     force(call)
-    srcref <- utils::getSrcref(sys.call())
-    withCallingHandlers({
-      expr
-    }, error = function(e) {
-      .hide_from_trace <- 0:1
-      e$srcref <- srcref
-      if (!inherits(err, "condition")) {
-        err <- new_error(err, call. = call)
+    srcref <- srcref %||% utils::getSrcref(sys.call())
+    withCallingHandlers(
+      {
+        expr
+      },
+      error = function(e) {
+        .hide_from_trace <- 0:1
+        e$srcref <- srcref
+        e$procsrcref <- NULL
+        if (!inherits(err, "condition")) {
+          err <- new_error(err, call. = call)
+        }
+        throw_error(err, parent = e)
       }
-      throw_error(err, parent = e)
-    })
+    )
   }
 
   # -- rethrowing conditions from C code ---------------------------------
@@ -339,11 +371,12 @@ err <- local({
       error = function(e) {
         .hide_from_trace <- 0:1
         e$srcref <- srcref
-        e$call <- call
+        e$procsrcref <- NULL
+        e[["call"]] <- call
         name <- native_name(.NAME)
         err <- new_error("Native call to `", name, "` failed", call. = call1)
         cerror <- if (inherits(e, "simpleError")) "c_error"
-        class(err) <- c(cerror, "rlib_error_3_0", "rlib_error", "rlang_error", "error", "condition")
+        class(err) <- c(cerror, "rlib_error_3_0", "rlib_error", "error", "condition")
         throw_error(err, parent = e)
       }
     )
@@ -373,11 +406,12 @@ err <- local({
       error = function(e) {
         .hide_from_trace <- 0:1
         e$srcref <- srcref
-        e$call <- call
+        e$procsrcref <- NULL
+        e[["call"]] <- call
         name <- native_name(.NAME)
         err <- new_error("Native call to `", name, "` failed", call. = call1)
         cerror <- if (inherits(e, "simpleError")) "c_error"
-        class(err) <- c(cerror, "rlib_error_3_0", "rlib_error", "rlang_error", "error", "condition")
+        class(err) <- c(cerror, "rlib_error_3_0", "rlib_error", "error", "condition")
         throw_error(err, parent = e)
       }
     )
@@ -396,7 +430,6 @@ err <- local({
   #' @return A condition object, with the trace added.
 
   add_trace_back <- function(cond, frame = NULL) {
-
     idx <- seq_len(sys.parent(1L))
     frames <- sys.frames()[idx]
 
@@ -406,7 +439,11 @@ err <- local({
     namespaces <- unlist(lapply(
       seq_along(frames),
       function(i) {
-        env_label(topenvx(environment(sys.function(i))))
+        if (is_operator(calls[[i]])) {
+          "o"
+        } else {
+          env_label(topenvx(environment(sys.function(i))))
+        }
       }
     ))
     pids <- rep(cond$`_pid` %||% Sys.getpid(), length(calls))
@@ -440,6 +477,7 @@ err <- local({
     pcs <- lapply(calls, function(c) process_call(list(call = c)))
     calls <- lapply(pcs, "[[", "call")
     srcrefs <- I(lapply(pcs, "[[", "srcref"))
+    procsrcrefs <- I(lapply(pcs, "[[", "procsrcref"))
 
     cond$trace <- new_trace(
       calls,
@@ -448,12 +486,18 @@ err <- local({
       namespaces = namespaces,
       scopes = scopes,
       srcrefs = srcrefs,
+      procsrcrefs = procsrcrefs,
       pids
     )
 
     cond
   }
 
+  is_operator <- function(cl) {
+    is.call(cl) && length(cl) >= 1 && is.symbol(cl[[1]]) &&
+      grepl("^[^.a-zA-Z]", as.character(cl[[1]]))
+  }
+
   mark_invisible_frames <- function(funs, frames) {
     visibles <- rep(TRUE, length(frames))
     hide <- lapply(frames, "[[", ".hide_from_trace")
@@ -465,7 +509,7 @@ err <- local({
 
     hide_from <- which(funs %in% names(invisible_frames))
     for (start in hide_from) {
-      hide_this <- invisible_frames[[ funs[start] ]]
+      hide_this <- invisible_frames[[funs[start]]]
       for (i in seq_along(hide_this)) {
         if (start + i > length(funs)) break
         if (funs[start + i] != hide_this[i]) break
@@ -482,7 +526,8 @@ err <- local({
     "cli::cli_abort" = c(
       "rlang::abort",
       "rlang:::signal_abort",
-      "base::signalCondition"),
+      "base::signalCondition"
+    ),
     "rlang::abort" = c("rlang:::signal_abort", "base::signalCondition")
   )
 
@@ -501,16 +546,30 @@ err <- local({
   }
 
   get_call_scope <- function(call, ns) {
-    if (is.na(ns)) return("global")
-    if (!is.call(call)) return("")
+    if (is.na(ns)) {
+      return("global")
+    }
+    if (!is.call(call)) {
+      return("")
+    }
     if (is.call(call[[1]]) &&
-        (call[[1]][[1]] == quote(`::`) || call[[1]][[1]] == quote(`:::`))) return("")
-    if (ns == "base") return("::")
-    if (! ns %in% loadedNamespaces()) return("")
+      (call[[1]][[1]] == quote(`::`) || call[[1]][[1]] == quote(`:::`))) {
+      return("")
+    }
+    if (ns == "base") {
+      return("::")
+    }
+    if (!ns %in% loadedNamespaces()) {
+      return("")
+    }
     name <- call_name(call)
     nsenv <- asNamespace(ns)$.__NAMESPACE__.
-    if (is.null(nsenv)) return("::")
-    if (is.null(nsenv$exports)) return(":::")
+    if (is.null(nsenv)) {
+      return("::")
+    }
+    if (is.null(nsenv$exports)) {
+      return(":::")
+    }
     if (exists(name, envir = nsenv$exports, inherits = FALSE)) {
       "::"
     } else if (exists(name, envir = asNamespace(ns), inherits = FALSE)) {
@@ -524,7 +583,7 @@ err <- local({
     topenv(x, matchThisEnv = err_env)
   }
 
-  new_trace <- function (calls, parents, visibles, namespaces, scopes, srcrefs, pids) {
+  new_trace <- function(calls, parents, visibles, namespaces, scopes, srcrefs, procsrcrefs, pids) {
     trace <- data.frame(
       stringsAsFactors = FALSE,
       parent = parents,
@@ -532,11 +591,12 @@ err <- local({
       namespace = namespaces,
       scope = scopes,
       srcref = srcrefs,
+      procsrcref = procsrcrefs,
       pid = pids
     )
-    trace$call <- calls
+    trace[["call"]] <- calls
 
-    class(trace) <- c("rlib_trace_3_0", "rlang_trace", "rlib_trace", "tbl", "data.frame")
+    class(trace) <- c("rlib_trace_3_0", "rlib_trace", "tbl", "data.frame")
     trace
   }
 
@@ -587,7 +647,7 @@ err <- local({
   }
 
   print_error <- function(x, trace = TRUE, class = TRUE,
-                          advice = !trace,  ...) {
+                          advice = !trace, ...) {
     writeLines(format_error(x, trace, class, advice, ...))
   }
 
@@ -667,27 +727,38 @@ err <- local({
 
   # -- condition message with cli ---------------------------------------
 
+  cnd_message_robust <- function(cond) {
+    class(cond) <- setdiff(class(cond), "rlib_error_3_0")
+    conditionMessage(cond) %||%
+      (if (inherits(cond, "interrupt")) "interrupt") %||%
+      ""
+  }
+
   cnd_message_cli <- function(cond, full = FALSE) {
     exp <- paste0(cli::col_yellow("!"), " ")
     add_exp <- is.null(names(cond$message))
+    msg <- cnd_message_robust(cond)
 
     c(
-      paste0(if (add_exp) exp, cond$message),
+      paste0(if (add_exp) exp, msg),
       if (inherits(cond$parent, "condition")) {
         msg <- if (full && inherits(cond$parent, "rlib_error_3_0")) {
           format(cond$parent,
-                 trace = FALSE,
-                 full = TRUE,
-                 class = FALSE,
-                 header = FALSE,
-                 advice = FALSE
+            trace = FALSE,
+            full = TRUE,
+            class = FALSE,
+            header = FALSE,
+            advice = FALSE
           )
+        } else if (inherits(cond$parent, "interrupt")) {
+          "interrupt"
         } else {
           conditionMessage(cond$parent)
         }
         add_exp <- substr(cli::ansi_strip(msg[1]), 1, 1) != "!"
         if (add_exp) msg[1] <- paste0(exp, msg[1])
-        c(format_header_line_cli(cond$parent, prefix = "Caused by error"),
+        c(
+          format_header_line_cli(cond$parent, prefix = "Caused by error"),
           msg
         )
       }
@@ -700,16 +771,18 @@ err <- local({
     exp <- "! "
     add_exp <- is.null(names(cond$message))
     c(
-      paste0(if (add_exp) exp, cond$message),
+      paste0(if (add_exp) exp, cnd_message_robust(cond)),
       if (inherits(cond$parent, "condition")) {
         msg <- if (full && inherits(cond$parent, "rlib_error_3_0")) {
           format(cond$parent,
-                 trace = FALSE,
-                 full = TRUE,
-                 class = FALSE,
-                 header = FALSE,
-                 advice = FALSE
+            trace = FALSE,
+            full = TRUE,
+            class = FALSE,
+            header = FALSE,
+            advice = FALSE
           )
+        } else if (inherits(cond$parent, "interrupt")) {
+          "interrupt"
         } else {
           conditionMessage(cond$parent)
         }
@@ -717,7 +790,8 @@ err <- local({
         if (add_exp) {
           msg[1] <- paste0(exp, msg[1])
         }
-        c(format_header_line_plain(cond$parent, prefix = "Caused by error"),
+        c(
+          format_header_line_plain(cond$parent, prefix = "Caused by error"),
           msg
         )
       }
@@ -744,17 +818,19 @@ err <- local({
       c("---", "Backtrace:", format_trace_cli(x$trace))
     }
 
-    c(p_class,
+    c(
+      p_class,
       p_header,
       p_msg,
       p_advice,
-      p_trace)
+      p_trace
+    )
   }
 
   format_header_line_cli <- function(x, prefix = NULL) {
     p_error <- format_error_heading_cli(x, prefix)
-    p_call <- format_call_cli(x$call)
-    p_srcref <- format_srcref_cli(conditionCall(x), x$srcref)
+    p_call <- format_call_cli(x[["call"]])
+    p_srcref <- format_srcref_cli(conditionCall(x), x$procsrcref %||% x$srcref)
     paste0(p_error, p_call, p_srcref, if (!is.null(conditionCall(x))) ":")
   }
 
@@ -789,15 +865,23 @@ err <- local({
 
   format_srcref_cli <- function(call, srcref = NULL) {
     ref <- get_srcref(call, srcref)
-    if (is.null(ref)) return("")
+    if (is.null(ref)) {
+      return("")
+    }
 
     link <- if (ref$file != "") {
-      cli::style_hyperlink(
-        cli::format_inline("{basename(ref$file)}:{ref$line}:{ref$col}"),
-        paste0("file://", ref$file),
-        params = c(line = ref$line, col = ref$col)
-      )
-
+      if (Sys.getenv("R_CLI_HYPERLINK_STYLE") == "iterm") {
+        cli::style_hyperlink(
+          cli::format_inline("{basename(ref$file)}:{ref$line}:{ref$col}"),
+          paste0("file://", ref$file, "#", ref$line, ":", ref$col)
+        )
+      } else {
+        cli::style_hyperlink(
+          cli::format_inline("{basename(ref$file)}:{ref$line}:{ref$col}"),
+          paste0("file://", ref$file),
+          params = c(line = ref$line, col = ref$col)
+        )
+      }
     } else {
       paste0("line ", ref$line)
     }
@@ -826,21 +910,23 @@ err <- local({
       rep(TRUE, nrow(x))
     }
 
-    srcref <- if ("srcref" %in% names(x)) {
+    srcref <- if ("srcref" %in% names(x) || "procsrcref" %in% names(x)) {
       vapply(
         seq_len(nrow(x)),
-        function(i) format_srcref_cli(x$call[[i]], x$srcref[[i]]),
+        function(i) format_srcref_cli(x[["call"]][[i]], x$procsrcref[[i]] %||% x$srcref[[i]]),
         character(1)
       )
     } else {
-      unname(vapply(x$call, format_srcref_cli, character(1)))
+      unname(vapply(x[["call"]], format_srcref_cli, character(1)))
     }
 
     lines <- paste0(
       cli::col_silver(format(x$num), ". "),
-      ifelse (visible, "", "| "),
+      ifelse(visible, "", "| "),
       scope,
-      vapply(x$call, format_trace_call_cli, character(1)),
+      vapply(seq_along(x$call), function(i) {
+        format_trace_call_cli(x$call[[i]], x$namespace[[i]])
+      }, character(1)),
       srcref
     )
 
@@ -852,10 +938,18 @@ err <- local({
     lines
   }
 
-  format_trace_call_cli <- function(call) {
+  format_trace_call_cli <- function(call, ns = "") {
+    envir <- tryCatch(asNamespace(ns), error = function(e) .GlobalEnv)
     cl <- trimws(format(call))
-    if (length(cl) > 1) { cl <- paste0(cl[1], " ", cli::symbol$ellipsis) }
-    fmc <- cli::code_highlight(cl)[1]
+    if (length(cl) > 1) {
+      cl <- paste0(cl[1], " ", cli::symbol$ellipsis)
+    }
+    # Older cli does not have 'envir'.
+    if ("envir" %in% names(formals(cli::code_highlight))) {
+      fmc <- cli::code_highlight(cl, envir = envir)[1]
+    } else {
+      fmc <- cli::code_highlight(cl)[1]
+    }
     cli::ansi_strtrim(fmc, cli::console_width() - 5)
   }
 
@@ -872,11 +966,13 @@ err <- local({
       c("---", "Backtrace:", format_trace_plain(x$trace))
     }
 
-    c(p_class,
+    c(
+      p_class,
       p_header,
       p_msg,
       p_advice,
-      p_trace)
+      p_trace
+    )
   }
 
   format_trace_plain <- function(x, ...) {
@@ -894,21 +990,21 @@ err <- local({
       rep(TRUE, nrow(x))
     }
 
-    srcref <- if ("srcref" %in% names(x)) {
+    srcref <- if ("srcref" %in% names(x) || "procsrfref" %in% names(x)) {
       vapply(
         seq_len(nrow(x)),
-        function(i) format_srcref_plain(x$call[[i]], x$srcref[[i]]),
+        function(i) format_srcref_plain(x[["call"]][[i]], x$procsrcref[[i]] %||% x$srcref[[i]]),
         character(1)
       )
     } else {
-      unname(vapply(x$call, format_srcref_plain, character(1)))
+      unname(vapply(x[["call"]], format_srcref_plain, character(1)))
     }
 
     lines <- paste0(
       paste0(format(x$num), ". "),
-      ifelse (visible, "", "| "),
+      ifelse(visible, "", "| "),
       scope,
-      vapply(x$call, format_trace_call_plain, character(1)),
+      vapply(x[["call"]], format_trace_call_plain, character(1)),
       srcref
     )
 
@@ -921,8 +1017,8 @@ err <- local({
 
   format_header_line_plain <- function(x, prefix = NULL) {
     p_error <- format_error_heading_plain(x, prefix)
-    p_call <- format_call_plain(x$call)
-    p_srcref <- format_srcref_plain(conditionCall(x), x$srcref)
+    p_call <- format_call_plain(x[["call"]])
+    p_srcref <- format_srcref_plain(conditionCall(x), x$procsrcref %||% x$srcref)
     paste0(p_error, p_call, p_srcref, if (!is.null(conditionCall(x))) ":")
   }
 
@@ -952,7 +1048,9 @@ err <- local({
 
   format_srcref_plain <- function(call, srcref = NULL) {
     ref <- get_srcref(call, srcref)
-    if (is.null(ref)) return("")
+    if (is.null(ref)) {
+      return("")
+    }
 
     link <- if (ref$file != "") {
       paste0(basename(ref$file), ":", ref$line, ":", ref$col)
@@ -965,7 +1063,9 @@ err <- local({
 
   format_trace_call_plain <- function(call) {
     fmc <- trimws(format(call)[1])
-    if (length(fmc) > 1) { fmc <- paste0(fmc[1], " ...") }
+    if (length(fmc) > 1) {
+      fmc <- paste0(fmc[1], " ...")
+    }
     strtrim(fmc, getOption("width") - 5)
   }
 
@@ -987,23 +1087,28 @@ err <- local({
   }
 
   process_call <- function(cond) {
-    cond[c("call", "srcref")] <- list(
-      call = if (is.null(cond$call)) {
+    cond[c("call", "srcref", "procsrcref")] <- list(
+      call = if (is.null(cond[["call"]])) {
         NULL
-      } else if (is.character(cond$call)) {
-        cond$call
+      } else if (is.character(cond[["call"]])) {
+        cond[["call"]]
       } else {
-        deparse(cond$call, nlines = 2)
+        deparse(cond[["call"]], nlines = 2)
       },
-      srcref = get_srcref(cond$call, cond$srcref)
+      srcref = NULL,
+      procsrcref = get_srcref(cond[["call"]], cond$procsrcref %||% cond$srcref)
     )
     cond
   }
 
   get_srcref <- function(call, srcref = NULL) {
     ref <- srcref %||% utils::getSrcref(call)
-    if (is.null(ref)) return(NULL)
-    if (inherits(ref, "processed_srcref")) return(ref)
+    if (is.null(ref)) {
+      return(NULL)
+    }
+    if (inherits(ref, "processed_srcref")) {
+      return(ref)
+    }
     file <- utils::getSrcFilename(ref, full.names = TRUE)[1]
     if (is.na(file)) file <- ""
     line <- utils::getSrcLocation(ref) %||% ""
@@ -1089,17 +1194,18 @@ err <- local({
 
   structure(
     list(
-      .internal        = err_env,
-      new_cond         = new_cond,
-      new_error        = new_error,
-      throw            = throw,
-      throw_error      = throw_error,
-      chain_error      = chain_error,
-      chain_call       = chain_call,
+      .internal = err_env,
+      new_cond = new_cond,
+      new_error = new_error,
+      throw = throw,
+      throw_error = throw_error,
+      chain_error = chain_error,
+      chain_call = chain_call,
       chain_clean_call = chain_clean_call,
-      add_trace_back   = add_trace_back,
-      process_call     = process_call,
-      onload_hook      = onload_hook,
+      add_trace_back = add_trace_back,
+      process_call = process_call,
+      onload_hook = onload_hook,
+      is_interactive = is_interactive,
       format = list(
         advice        = format_advice,
         call          = format_call,
@@ -1111,18 +1217,17 @@ err <- local({
         trace         = format_trace
       )
     ),
-    class = c("standalone_errors", "standalone"))
+    class = c("standalone_errors", "standalone")
+  )
 })
 
 # These are optional, and feel free to remove them if you prefer to
 # call them through the `err` object.
 
-new_cond         <- err$new_cond
-new_error        <- err$new_error
-throw            <- err$throw
-throw_error      <- err$throw_error
-chain_error      <- err$chain_error
-chain_call       <- err$chain_call
+new_cond <- err$new_cond
+new_error <- err$new_error
+throw <- err$throw
+throw_error <- err$throw_error
+chain_error <- err$chain_error
+chain_call <- err$chain_call
 chain_clean_call <- err$chain_clean_call
-
-# nocov end
