@@ -1,6 +1,10 @@
-
 as_json <- function(cast) {
-  stopifnot(inherits(cast, "asciicast"))
+  if (!inherits(cast, "asciicast")) {
+    throw(cli::format_error(c(
+      "{.var cast} must be an {.cls asciicast}, object.",
+      i = "It is a {.type {cast}}."
+    )))
+  }
   con <- textConnection(NULL, "w", local = TRUE)
   on.exit(close(con), add = TRUE)
   write_json_con(cast, con)
@@ -13,10 +17,14 @@ write_json_con <- function(cast, con) {
   cat("\n", file = con)
 
   # data
-  cat(sep = "", file = con,
-      paste0("[", cast$output$time, ", ",
-             encode_str(cast$output$type), ", ",
-             encode_str(cast$output$data), "]", "\n"))
+  cat(
+    sep = "", file = con,
+    paste0(
+      "[", cast$output$time, ", ",
+      encode_str(cast$output$type), ", ",
+      encode_str(cast$output$data), "]", "\n"
+    )
+  )
 }
 
 #' Write an ascii cast to file
@@ -34,8 +42,9 @@ write_json_con <- function(cast, con) {
 #' cast <- record(script)
 #' json <- tempfile(fileext = ".json")
 #' write_json(cast, json)
-#' \dontshow{unlink(json, recursive = TRUE)}
-
+#' \dontshow{
+#' unlink(json, recursive = TRUE)
+#' }
 write_json <- function(cast, path) {
   con <- file(path, open = "wb")
   on.exit(close(con), add = TRUE)
